@@ -15,7 +15,7 @@ checkInstalledVersion()
   # version of DART being installed has to be greater than the current DART version
   if [ -f ${DARTMANIFEST} ]; then
       DARTPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${DARTMANIFEST})
-      DARTCURRVERSION=4.10.01075
+      DARTCURRVERSION=4.10.03104
 
       if [ $(version $DARTCURRVERSION) -le $(version $DARTPREVVERSION) ]; then
         failed=true
@@ -50,7 +50,7 @@ UNINSTALL="${VPNBIN}/dart_uninstall.sh"
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.10.01075-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.03104-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
 
 DARTMANIFEST="${INSTPREFIX}/ACManifestDART.xml"
 
@@ -306,11 +306,10 @@ fi
 
 # if the update cache utility exists then update the menu cache
 # otherwise on some gnome systems, the short cut will disappear
-# after user logoff or reboot. This is neccessary on some
-# gnome desktops(Ubuntu 10.04)
-if [ -f "${NEWTEMP}/cisco-anyconnect-dart.desktop" ]; then
-    echo "Installing "${NEWTEMP}/cisco-anyconnect-dart.desktop >> /tmp/${LOGFNAME}
-    ${INSTALL} -o root -m 644 ${NEWTEMP}/cisco-anyconnect-dart.desktop /usr/share/applications || exit 1
+# after user logoff or reboot. This is neccessary on some gnome desktops.
+if [ -f "${NEWTEMP}/com.cisco.anyconnect.dart.desktop" ]; then
+    echo "Installing "${NEWTEMP}/com.cisco.anyconnect.dart.desktop >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 644 ${NEWTEMP}/com.cisco.anyconnect.dart.desktop /usr/share/applications || exit 1
     if [ -x "/usr/share/gnome-menus/update-gnome-menus-cache" ]; then
         for CACHE_FILE in $(ls /usr/share/applications/desktop.*.cache); do
             echo "updating ${CACHE_FILE}" > /tmp/${LOGFNAME}
@@ -318,7 +317,7 @@ if [ -f "${NEWTEMP}/cisco-anyconnect-dart.desktop" ]; then
         done
     fi
 else
-    echo "${NEWTEMP}/cisco-anyconnect-dart.desktop does not exist. It will not be installed."
+    echo "${NEWTEMP}/com.cisco.anyconnect.dart.desktop does not exist. It will not be installed."
 fi
 
 if [ -f "${NEWTEMP}/resources/dartTypical.png" ]; then
