@@ -35,7 +35,7 @@ FILELIST="${CONFIGDIR}/AnyConnectConfig.xml \
           ${BINDIR}/SetUIDTool_dart \
           ${MENUDIR}/cisco-anyconnect-dart.menu \
           ${DIRECTORYDIR}/cisco-anyconnect-dart.directory \
-          ${DESKTOPDIR}/cisco-anyconnect-dart.desktop \
+          ${DESKTOPDIR}/com.cisco.anyconnect.dart.desktop \
           ${ICONSDIR}/hicolor/48x48/apps/cisco-anyconnect-dart.png \
           ${ICONSDIR}/hicolor/64x64/apps/cisco-anyconnect-dart.png \
           ${ICONSDIR}/hicolor/96x96/apps/cisco-anyconnect-dart.png \
