@@ -14,7 +14,7 @@ checkVersionFeasibilityWithStandaloneNVM()
   failed=false
   # version of VPN being installed has to be greater than the installed standalone NVM version
   if [ -f ${NVMMANIFEST} ]; then
-      VPNVERSION=4.10.01075
+      VPNVERSION=4.10.03104
       NVMVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
 
       if [ $(version $VPNVERSION) -lt $(version $NVMVERSION) ]; then
@@ -35,7 +35,7 @@ checkInstalledVersion()
   # version of VPN being installed has to be greater than the current VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      VPNCURRVERSION=4.10.01075
+      VPNCURRVERSION=4.10.03104
 
       if [ $(version $VPNCURRVERSION) -le $(version $VPNPREVVERSION) ]; then
         failed=true
@@ -92,7 +92,7 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.10.01075-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.03104-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -309,11 +309,11 @@ ${INSTALL} -o root -m 755 ${NEWTEMP}/libacciscocrypto.so ${LIBDIR} || exitInstal
 echo "Installing "${NEWTEMP}/cfom.so >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/cfom.so ${LIBDIR} || exitInstallation 1
 
-echo "Installing "${NEWTEMP}/libaccurl.so.4.5.0 >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${NEWTEMP}/libaccurl.so.4.5.0 ${LIBDIR} || exitInstallation 1
+echo "Installing "${NEWTEMP}/libaccurl.so.4.7.0 >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 755 ${NEWTEMP}/libaccurl.so.4.7.0 ${LIBDIR} || exitInstallation 1
 
 echo "Creating symlink "${NEWTEMP}/libaccurl.so.4 >> /tmp/${LOGFNAME}
-ln -s ${LIBDIR}/libaccurl.so.4.5.0 ${LIBDIR}/libaccurl.so.4 || exitInstallation 1
+ln -s ${LIBDIR}/libaccurl.so.4.7.0 ${LIBDIR}/libaccurl.so.4 || exitInstallation 1
 
 if [ -f "${NEWTEMP}/libvpnipsec.so" ]; then
     echo "Installing "${NEWTEMP}/libvpnipsec.so >> /tmp/${LOGFNAME}
@@ -399,6 +399,13 @@ else
     echo "${NEWTEMP}/acwebhelper does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/acextwebhelper" ]; then
+    echo "Installing "${NEWTEMP}/acextwebhelper >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 755 ${NEWTEMP}/acextwebhelper ${BINDIR} || exitInstallation 1
+else
+    echo "${NEWTEMP}/acextwebhelper does not exist. It will not be installed."
+fi
+
 echo "Installing "${NEWTEMP}/vpn >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/vpn ${BINDIR} || exitInstallation 1
 
@@ -441,11 +448,10 @@ fi
 
 # if the update cache utility exists then update the menu cache
 # otherwise on some gnome systems, the short cut will disappear
-# after user logoff or reboot. This is neccessary on some
-# gnome desktops(Ubuntu 10.04)
-if [ -f "${NEWTEMP}/cisco-anyconnect.desktop" ]; then
-    echo "Installing ${NEWTEMP}/cisco-anyconnect.desktop" >> /tmp/${LOGFNAME}
-    ${INSTALL} -o root -m 644 ${NEWTEMP}/cisco-anyconnect.desktop /usr/share/applications/
+# after user logoff or reboot. This is neccessary on some gnome desktops.
+if [ -f "${NEWTEMP}/com.cisco.anyconnect.gui.desktop" ]; then
+    echo "Installing ${NEWTEMP}/com.cisco.anyconnect.gui.desktop" >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 644 ${NEWTEMP}/com.cisco.anyconnect.gui.desktop /usr/share/applications/
     if [ -x "/usr/share/gnome-menus/update-gnome-menus-cache" ]; then
         for CACHE_FILE in $(ls /usr/share/applications/desktop.*.cache); do
             echo "updating ${CACHE_FILE}" >> /tmp/${LOGFNAME}
@@ -453,7 +459,7 @@ if [ -f "${NEWTEMP}/cisco-anyconnect.desktop" ]; then
         done
     fi
 else
-    echo "${NEWTEMP}/anyconnect.desktop does not exist. It will not be installed."
+    echo "${NEWTEMP}/com.cisco.anyconnect.gui.desktop does not exist. It will not be installed."
 fi
 
 if [ -f "${NEWTEMP}/ACManifestVPN.xml" ]; then
@@ -573,8 +579,6 @@ RESTRICT_TUNNEL_PROTOCOLS_TAG="RestrictTunnelProtocols"
 RESTRICT_WEB_LAUNCH_TAG="RestrictWebLaunch"
 STRICT_CERTIFICATE_TRUST_TAG="StrictCertificateTrust"
 EXCLUDE_PEM_FILE_CERT_STORE_TAG="ExcludePemFileCertStore"
-EXCLUDE_WIN_NATIVE_CERT_STORE_TAG="ExcludeWinNativeCertStore"
-EXCLUDE_MAC_NATIVE_CERT_STORE_TAG="ExcludeMacNativeCertStore"
 EXCLUDE_FIREFOX_NSS_CERT_STORE_TAG="ExcludeFirefoxNSSCertStore"
 ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER_TAG="AllowSoftwareUpdatesFromAnyServer"
 ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER_TAG="AllowComplianceModuleUpdatesFromAnyServer"
@@ -587,6 +591,8 @@ ALLOW_HELP_UPDATES_FROM_ANY_SERVER_TAG="AllowHelpUpdatesFromAnyServer"
 ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER_TAG="AllowResourceUpdatesFromAnyServer"
 ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER_TAG="AllowLocalizationUpdatesFromAnyServer"
 AUTHORIZED_SERVER_LIST_TAG="AuthorizedServerList"
+RESTRICT_SERVER_CERT_STORE_TAG="RestrictServerCertStore"
+OCSP_REVOCATION_TAG="OCSPRevocation"
 
 if $IS_PRE_DEPLOY; then
     if [ -d "${PROFILE_IMPORT_DIR}" ]; then
@@ -612,8 +618,6 @@ if [ -f "${TRANSFORM_FILE}" ] ; then
     RESTRICT_WEB_LAUNCH=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_WEB_LAUNCH_TAG})
     STRICT_CERTIFICATE_TRUST=$(getProperty "${TRANSFORM_FILE}" ${STRICT_CERTIFICATE_TRUST_TAG})
     EXCLUDE_PEM_FILE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_PEM_FILE_CERT_STORE_TAG})
-    EXCLUDE_WIN_NATIVE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_WIN_NATIVE_CERT_STORE_TAG})
-    EXCLUDE_MAC_NATIVE_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_MAC_NATIVE_CERT_STORE_TAG})
     EXCLUDE_FIREFOX_NSS_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${EXCLUDE_FIREFOX_NSS_CERT_STORE_TAG})
     ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER_TAG})
     ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER_TAG})
@@ -626,6 +630,8 @@ if [ -f "${TRANSFORM_FILE}" ] ; then
     ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER_TAG})
     ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER_TAG})
     AUTHORIZED_SERVER_LIST=$(getProperty "${TRANSFORM_FILE}" ${AUTHORIZED_SERVER_LIST_TAG})
+    RESTRICT_SERVER_CERT_STORE=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_SERVER_CERT_STORE_TAG})
+    OCSP_REVOCATION=$(getProperty "${TRANSFORM_FILE}" ${OCSP_REVOCATION_TAG})
 fi
 
 # if disable phone home is specified, remove the phone home plugin and any data folder
@@ -650,8 +656,6 @@ ${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
                                     rwl=${RESTRICT_WEB_LAUNCH:-false} \
                                     sct=${STRICT_CERTIFICATE_TRUST:-false} \
                                     epf=${EXCLUDE_PEM_FILE_CERT_STORE:-false} \
-                                    ewn=${EXCLUDE_WIN_NATIVE_CERT_STORE:-false} \
-                                    emn=${EXCLUDE_MAC_NATIVE_CERT_STORE:-false} \
                                     efn=${EXCLUDE_FIREFOX_NSS_CERT_STORE:-false} \
                                     upsu=${ALLOW_SOFTWARE_UPDATES_FROM_ANY_SERVER:-true} \
                                     upcu=${ALLOW_COMPLIANCE_MODULE_UPDATES_FROM_ANY_SERVER:-true} \
@@ -663,7 +667,9 @@ ${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
                                     uphlp=${ALLOW_HELP_UPDATES_FROM_ANY_SERVER:-true} \
                                     upres=${ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER:-true} \
                                     uploc=${ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER:-true} \
-                                    upal=${AUTHORIZED_SERVER_LIST}
+                                    upal=${AUTHORIZED_SERVER_LIST} \
+                                    rsc=${RESTRICT_SERVER_CERT_STORE:-false} \
+                                    or=${OCSP_REVOCATION:-false}
 
 # Attempt to install the init script in the proper place
 
